16.85. cdist-type__locale(7) — cdist 6.1.1 documentation

# 16.85. cdist-type__locale(7)

## 16.85.1. NAME

cdist-type__locale - Configure locales

## 16.85.2. DESCRIPTION

This cdist type allows you to setup locales. On systems that don't support locale setting like alpine/musl libc, it is a no-op.

## 16.85.3. OPTIONAL PARAMETERS

state
  'present' or 'absent', defaults to present

## 16.85.4. EXAMPLES

    # Add locale de_CH.UTF-8
    __locale de_CH.UTF-8

    # Same as above, but more explicit
    __locale de_CH.UTF-8 --state present

    # Remove colourful British English
    __locale en_GB.UTF-8 --state absent

## 16.85.5. SEE ALSO

locale(1), localedef(1), cdist-type__locale_system(7)

## 16.85.6. AUTHORS

Nico Schottelius <nico-cdist--@--schottelius.org>

## 16.85.7. COPYING

Copyright (C) 2013-2019 Nico Schottelius. Free use of this software is granted under the terms of the GNU General Public License version 3 or later (GPLv3+).